@@ -1,5 +1,6 @@
-#!/usr/bin/perl
-##!/home/utils/perl-5.8.8/bin/perl
+#!/home/utils/perl-5.8.8/bin/perl
+##!/home/utils/perl5/perlbrew/perls/5.20.1-007/bin/perl
+##!/usr/bin/perl
 ##!/home/utils/perl-5.8.6/bin/perl
 ##!/home/utils/perl-5.20/5.20.1-006/bin/perl
 use warnings;
@@ -7,8 +8,10 @@ use strict;
 
 #use lib '/home/ate/scripts/regression/';
 use lib 'lib';
-use Debug::Statements qw(d d0 d1 d2 d3 D ls);
+#use Debug::Statements qw(d d0 d1 d2 d3 D ls);
+use Debug::Statements ':all';
 
+# Sample variables which we want to print
 my $myvar = 'some value';
 my @list = ('zero', 1, 'two', "3");
 my %hash = ('one' => 2, 'three' => 4);
@@ -20,8 +23,7 @@ my %nestedhash = (
     },
 );
 
-# d0 and D are the same function.  They always print, regardless of $d
-d0 '$myvar';
+# D always prints, regardless of $d
 D '$myvar';
 
 my $d = 1;
@@ -34,7 +36,7 @@ d '@list %hash @nestedlist %nestedhash';
 d2 '$myvar'; # does not print because $d < 2
 $d = 2;
 d2 '$myvar'; # prints
-
+exit;
 
 # Prints ls -l of file or directory
 ls($0);
